@@ -39,7 +39,7 @@ def readFile(file):
             f.close()
             return(lines)
     else:
-        return('NA')
+        sys.exit('%s not found' % file)
 
 def addToDict(dict, groupID, seqID, type):
     if not groupID in dict:
@@ -53,9 +53,15 @@ def addToDict(dict, groupID, seqID, type):
             dict[groupID] = '%s\n%s\tduplicated (%s)\t%s' % (dict[groupID], groupID, type, seqID)
     return(dict)
 
-def mode1(ppFile, coreDir, coreSet, queryID):
+def mode1(ppFile, missingGr, coreDir, coreSet, queryID):
     noCutoff = []
     assessment = {}
+    # dict used to group genes into similar/dissimilar/missing
+    geneCat = {}
+    geneCat['similar'] = []
+    geneCat['dissimilar'] = []
+    geneCat['missing'] = []
+    # validate orthologs
     for line in readFile(ppFile):
         groupID = line.split('\t')[0]
         if queryID in line.split('\t')[2]:
@@ -68,25 +74,47 @@ def mode1(ppFile, coreDir, coreSet, queryID):
                         meanGroup = float(l.split('\t')[1].strip())
                 if meanFas >= meanGroup:
                     assessment = addToDict(assessment, groupID, line.split('\t')[2], 'similar')
+                    geneCat['similar'].append(line.strip()+'\t0')
                 else:
                     assessment = addToDict(assessment, groupID, line.split('\t')[2], 'dissimilar')
+                    geneCat['dissimilar'].append(line.strip()+'\t1')
             else:
                 noCutoff.append(groupID)
+        else:
+            if not groupID == 'geneID':
+                if groupID in missingGr:
+                    geneCat['missing'].append(line.strip()+'\t0')
+                else:
+                    geneCat['similar'].append(line.strip()+'\t0')
+    # create new pp file
+    newPP = '%s.mod' % ppFile
+    newPPfile = open(newPP, 'w')
+    newPPfile.write('geneID\tncbiID\torthoID\tFAS\tAssessment\n')
+    newPPfile.write('%s\n' % '\n'.join(geneCat['dissimilar']))
+    newPPfile.write('%s\n' % '\n'.join(geneCat['similar']))
+    newPPfile.write('%s\n' % '\n'.join(geneCat['missing']))
+    newPPfile.close()
+    shutil.move('%s.mod' % ppFile, ppFile)
     return(assessment, noCutoff)
 
-def mode2(ppFile, coreDir, coreSet, queryID, outDir):
+def mode2(ppFile, missingGr, coreDir, coreSet, queryID, outDir):
     noCutoff = []
     assessment = {}
+    # dict used to group genes into similar/dissimilar/missing
+    geneCat = {}
+    geneCat['similar'] = []
+    geneCat['dissimilar'] = []
+    geneCat['missing'] = []
     # get refspec for each group
     groupRefspec = {}
     refspecFile = '%s/%s/%s/last_refspec.txt' % (outDir, coreSet, queryID)
     for g in readFile(refspecFile):
         groupRefspec[g.split('\t')[0]] = g.split('\t')[1]
-    # do assessment
+    # validate orthologs
     for line in readFile(ppFile):
         groupID = line.split('\t')[0]
         if queryID in line.split('\t')[2]:
-            meanFas = statistics.mean((float(line.split('\t')[3]), float(line.split('\t')[4].strip())))
+            meanFas = float(line.split('\t')[3]) #statistics.mean((float(line.split('\t')[3]), float(line.split('\t')[4].strip())))
             scoreFile = '%s/core_orthologs/%s/%s/fas_dir/cutoff_dir/2.cutoff' % (coreDir, coreSet, groupID)
             if os.path.exists(scoreFile):
                 meanRefspec = 0
@@ -95,19 +123,42 @@ def mode2(ppFile, coreDir, coreSet, queryID, outDir):
                         meanRefspec = float(l.split('\t')[1].strip())
                 if meanFas >= meanRefspec:
                     assessment = addToDict(assessment, groupID, line.split('\t')[2], 'similar')
+                    geneCat['similar'].append(line.strip()+'\t0')
                 else:
                     assessment = addToDict(assessment, groupID, line.split('\t')[2], 'dissimilar')
+                    geneCat['dissimilar'].append(line.strip()+'\t1')
             else:
                 noCutoff.append(groupID)
+        else:
+            if not groupID == 'geneID':
+                if groupID in missingGr:
+                    geneCat['missing'].append(line.strip()+'\t0')
+                else:
+                    geneCat['similar'].append(line.strip()+'\t0')
+    # create new pp file
+    newPP = '%s.mod' % ppFile
+    newPPfile = open(newPP, 'w')
+    newPPfile.write('geneID\tncbiID\torthoID\tFAS\tAssessment\n')
+    newPPfile.write('%s\n' % '\n'.join(geneCat['dissimilar']))
+    newPPfile.write('%s\n' % '\n'.join(geneCat['similar']))
+    newPPfile.write('%s\n' % '\n'.join(geneCat['missing']))
+    newPPfile.close()
+    shutil.move('%s.mod' % ppFile, ppFile)
     return(assessment, noCutoff)
 
-def mode3(ppFile, coreDir, coreSet, queryID):
+def mode3(ppFile, missingGr, coreDir, coreSet, queryID):
     noCutoff = []
     assessment = {}
+    # dict used to group genes into similar/dissimilar/missing
+    geneCat = {}
+    geneCat['similar'] = []
+    geneCat['dissimilar'] = []
+    geneCat['missing'] = []
+    # validate orthologs
     for line in readFile(ppFile):
         groupID = line.split('\t')[0]
         if queryID in line.split('\t')[2]:
-            meanFas = statistics.mean((float(line.split('\t')[3]), float(line.split('\t')[4].strip())))
+            meanFas = float(line.split('\t')[3]) #statistics.mean((float(line.split('\t')[3]), float(line.split('\t')[4].strip())))
             scoreFile = '%s/core_orthologs/%s/%s/fas_dir/cutoff_dir/1.cutoff' % (coreDir, coreSet, groupID)
             if os.path.exists(scoreFile):
                 LCL = 0
@@ -120,15 +171,38 @@ def mode3(ppFile, coreDir, coreSet, queryID):
                 # if LCL <= meanFas <= UCL:
                 if LCL <= meanFas:
                     assessment = addToDict(assessment, groupID, line.split('\t')[2], 'similar')
+                    geneCat['similar'].append(line.strip()+'\t0')
                 else:
                     assessment = addToDict(assessment, groupID, line.split('\t')[2], 'dissimilar')
+                    geneCat['dissimilar'].append(line.strip()+'\t1')
             else:
                 noCutoff.append(groupID)
+        else:
+            if not groupID == 'geneID':
+                if groupID in missingGr:
+                    geneCat['missing'].append(line.strip()+'\t0')
+                else:
+                    geneCat['similar'].append(line.strip()+'\t0')
+    # create new pp file
+    newPP = '%s.mod' % ppFile
+    newPPfile = open(newPP, 'w')
+    newPPfile.write('geneID\tncbiID\torthoID\tFAS\tAssessment\n')
+    newPPfile.write('%s\n' % '\n'.join(geneCat['dissimilar']))
+    newPPfile.write('%s\n' % '\n'.join(geneCat['similar']))
+    newPPfile.write('%s\n' % '\n'.join(geneCat['missing']))
+    newPPfile.close()
+    shutil.move('%s.mod' % ppFile, ppFile)
     return(assessment, noCutoff)
 
-def mode4(ppFile, coreDir, coreSet, queryID):
+def mode4(ppFile, missingGr, coreDir, coreSet, queryID):
     noCutoff = []
     assessment = {}
+    # dict used to group genes into similar/dissimilar/missing
+    geneCat = {}
+    geneCat['similar'] = []
+    geneCat['dissimilar'] = []
+    geneCat['missing'] = []
+    # validate orthologs
     for line in readFile(ppFile):
         groupID = line.split('\t')[0]
         if queryID in line.split('\t')[2]:
@@ -146,16 +220,34 @@ def mode4(ppFile, coreDir, coreSet, queryID):
                     check = abs((length - meanLen) / stdevLen)
                     if check <= 1:
                         assessment = addToDict(assessment, groupID, line.split('\t')[2], 'complete')
+                        geneCat['similar'].append(line.strip()+'\t0')
                     else:
                         assessment = addToDict(assessment, groupID, line.split('\t')[2], 'fragmented')
+                        geneCat['dissimilar'].append(line.strip()+'\t1')
                 else:
                     if abs(length - meanLen) > 0:
                         assessment = addToDict(assessment, groupID, line.split('\t')[2], 'complete')
+                        geneCat['similar'].append(line.strip()+'\t0')
                     else:
                         assessment = addToDict(assessment, groupID, line.split('\t')[2], 'fragmented')
-                    # noCutoff.append(groupID)
+                        geneCat['dissimilar'].append(line.strip()+'\t1')
             else:
                 noCutoff.append(groupID)
+        else:
+            if not groupID == 'geneID':
+                if groupID in missingGr:
+                    geneCat['missing'].append(line.strip()+'\t0')
+                else:
+                    geneCat['similar'].append(line.strip()+'\t0')
+    # create new pp file
+    newPP = '%s.mod' % ppFile
+    newPPfile = open(newPP, 'w')
+    newPPfile.write('geneID\tncbiID\torthoID\tFAS\tAssessment\n')
+    newPPfile.write('%s\n' % '\n'.join(geneCat['dissimilar']))
+    newPPfile.write('%s\n' % '\n'.join(geneCat['similar']))
+    newPPfile.write('%s\n' % '\n'.join(geneCat['missing']))
+    newPPfile.close()
+    shutil.move('%s.mod' % ppFile, ppFile)
     return(assessment, noCutoff)
 
 def mode5(ppFile, coreDir, coreSet, queryID):
@@ -224,9 +316,7 @@ def writeReport(assessment, outDir, coreDir, coreSet, queryID, mode):
     fullFile.close()
     # write summary report
     summaryFile = open('%s/%s/%s/mode_%s/summary.txt' % (outDir, coreSet, queryID, mode), 'w')
-    print('%s/%s/%s/mode_%s/full.txt' % (outDir, coreSet, queryID, mode))
     type = [x.split('\t')[1] for x in open('%s/%s/%s/mode_%s/full.txt' % (outDir, coreSet, queryID, mode)).readlines()]
-    print(len(type))
     groupID = [x.split('\t')[0] for x in open('%s/%s/%s/mode_%s/full.txt' % (outDir, coreSet, queryID, mode)).readlines()]
     dup = [item for item, count in collections.Counter(groupID).items() if count > 1]
     coreGroups = os.listdir(coreDir + '/core_orthologs/' + coreSet)
@@ -243,18 +333,23 @@ def doAssessment(ppDir, coreDir, coreSet, queryID, outDir, mode):
     assessment = {}
     noCutoff = []
     # assess completeness
+    missingFile = '%s/%s/%s/missing.txt' % (outDir, coreSet, queryID)
+    missingGr = []
+    if os.path.exists(missingFile):
+        with open(missingFile) as f:
+            missingGr = [line.rstrip('\n') for line in f]
     if mode == 1:
         ppFile = '%s/mode1.phyloprofile' % (ppDir)
-        (assessment, noCutoff) = mode1(ppFile, coreDir, coreSet, queryID)
+        (assessment, noCutoff) = mode1(ppFile, missingGr, coreDir, coreSet, queryID)
     elif mode == 2:
         ppFile = '%s/mode23.phyloprofile' % (ppDir)
-        (assessment, noCutoff) = mode2(ppFile, coreDir, coreSet, queryID, outDir)
+        (assessment, noCutoff) = mode2(ppFile, missingGr, coreDir, coreSet, queryID, outDir)
     elif mode == 3:
         ppFile = '%s/mode23.phyloprofile' % (ppDir)
-        (assessment, noCutoff) = mode3(ppFile, coreDir, coreSet, queryID)
+        (assessment, noCutoff) = mode3(ppFile, missingGr, coreDir, coreSet, queryID)
     elif mode == 4:
         ppFile = '%s/length.phyloprofile' % (ppDir)
-        (assessment, noCutoff) = mode4(ppFile, coreDir, coreSet, queryID)
+        (assessment, noCutoff) = mode4(ppFile, missingGr, coreDir, coreSet, queryID)
     elif mode == 5:
         ppFile = '%s/mode4.phyloprofile' % (ppDir)
         (assessment, noCutoff) = mode5(ppFile, coreDir, coreSet, queryID)
@@ -325,14 +420,14 @@ def assessCompteness(args):
     mergedFull.close()
 
 def main():
-    version = '0.0.8'
+    version = '0.0.9'
     parser = argparse.ArgumentParser(description='You are running fcat version ' + str(version) + '.')
     required = parser.add_argument_group('required arguments')
     optional = parser.add_argument_group('optional arguments')
     required.add_argument('-d', '--coreDir', help='Path to core set directory, where folder core_orthologs can be found', action='store', default='', required=True)
     required.add_argument('-c', '--coreSet', help='Name of core set, which is subfolder within coreDir/core_orthologs/ directory', action='store', default='', required=True)
-    required.add_argument('-o', '--outDir', help='Path to output directory', action='store', default='')
-    required.add_argument('--queryID', help='ID of taxon of interest (e.g. HUMAN@9606@3)', action='store', default='', type=str)
+    required.add_argument('-o', '--outDir', help='Path to output directory', action='store', default='', required=True)
+    required.add_argument('--queryID', help='ID of taxon of interest (e.g. HUMAN@9606@3)', action='store', default='', type=str, required=True)
     optional.add_argument('-m', '--mode',
                         help='Score cutoff mode. (0) all modes, (1) mean of all-vs-all FAS scores, (2) mean FAS of refspec seed, (3) lower endpoint of CI of all-vs-all FAS scores, (4) mean and stdev of sequence length, (5) mean consensus, (6) reference consensus',
                         action='store', default=0, choices=[0,1,2,3,4,5,6], type=int)
