@@ -19,14 +19,14 @@ import sys
 import os
 import argparse
 from pathlib import Path
-from Bio import SeqIO
-import subprocess
-import multiprocessing as mp
-import shutil
-from tqdm import tqdm
-import time
-import statistics
-import collections
+# from Bio import SeqIO
+# import subprocess
+# import multiprocessing as mp
+# import shutil
+# from tqdm import tqdm
+# import time
+# import statistics
+# import collections
 
 def checkFileExist(file, msg):
     if not os.path.exists(os.path.abspath(file)):
@@ -39,7 +39,7 @@ def readFile(file):
             f.close()
             return(lines)
     else:
-        return('NA')
+        sys.exit('%s not found' % file)
 
 def mergePP(args):
     coreDir = os.path.abspath(args.coreDir)
@@ -74,7 +74,7 @@ def mergePP(args):
         mode23File.close()
 
 def main():
-    version = '0.0.8'
+    version = '0.0.9'
     parser = argparse.ArgumentParser(description='You are running fcat version ' + str(version) + '.')
     parser.add_argument('-d', '--coreDir', help='Path to core set directory, where folder core_orthologs can be found', action='store', default='', required=True)
     parser.add_argument('-c', '--coreSet', help='Name of core set, which is subfolder within coreDir/core_orthologs/ directory', action='store', default='', required=True)
